==> tempserver-0.0.1.tar.gz: tempserver-0.0.1/tempfetch.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import socket, sys
from time import sleep, strftime
import datetime

import rrdtool

def fetch( host, port=49000 ):
    """Download the raw data from host:port and do some parsing on it"""
    csock = socket.socket( socket.AF_INET, socket.SOCK_STREAM )
    csock.connect( ( host, port ) )
    data = csock.makefile( 'r' ).readline().strip()
    csock.close()

    ret_val = []
    for sensor in data.split( ',' ):
        val = sensor.split( '=' )
        if len( val ) == 2:
            ret_val.append( (val[0], val[1] ) )
        elif len( sensor ) == 0:
            pass
        else:
            print "warning: got malformed data: '%s'" % sensor
    
    return ret_val

def log( path, host, sensor, value ):
    """logs to path/host-sensor.rrd, if file doesn't exist create it"""
    try:
        touch_file = open( "%s/%s-%s.rrd" %( path, host, sensor ), 'r' )
        touch_file.close()
    except:
        # File didn't exist create it!
        # FIXME: support for diffrent ranges would be nice!
        rrdtool.create( "%s/%s-%s.rrd" %( path, host, sensor ),
                        '-s', '600', "DS:%s:GAUGE:1200:-300:300" % sensor,
                        "RRA:AVERAGE:0.5:1:9600" )
        print "Created new rrd file"
        
    
    print "%s: %s %sC @ %s" %( strftime( "%x %H:%M" ), sensor, value, host )
    rrdtool.update( "%s/%s-%s.rrd" %( path, host, sensor ),
                    "-t%s" % sensor , "N:%s" % value )

# -- main --
if __name__ == '__main__':
    # 10min, logga HDD temp, enbart 1 data fält
    # (temp timeout 1200sek)
    # rrdtool create testfil.rrd -s 600  DS:sda:GAUGE:1200:-300:300 RRA:AVERAGE:0.5:1:9600
    # Exempel på hur denna såg ut...
    print "dumbfetcher/logger test"
    
    HOSTS=["dunwich", "arkham", "gug", "talulah"]
    PATH="testdata"
    
    while True:
        for x in HOSTS:
            try:
                for sensor in fetch( x ):
                    log( PATH, x, sensor[0], sensor[1] )
            except:
                print "Failed to connect to %s, skipping" % x
        
        sleep( 600 )

==> tempserver-0.0.2.tar.gz: tempserver-0.0.2/tempfetch.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

import socket, sys
from time import sleep, strftime
import datetime

import rrdtool

def fetch( host, port=49000 ):
    """Download the raw data from host:port and do some parsing on it"""
    csock = socket.socket( socket.AF_INET, socket.SOCK_STREAM )
    csock.connect( ( host, port ) )
    data = csock.makefile( 'r' ).readline().strip()
    csock.close()

    ret_val = []
    for sensor in data.split( ',' ):
        val = sensor.split( '=' )
        if len( val ) == 2:
            ret_val.append( (val[0], val[1] ) )
        elif len( sensor ) == 0:
            pass
        else:
            print "warning: got malformed data: '%s'" % sensor
    
    return ret_val

def log( path, host, sensor, value ):
    """logs to path/host-sensor.rrd, if file doesn't exist create it"""
    try:
        touch_file = open( "%s/%s-%s.rrd" %( path, host, sensor ), 'r' )
        touch_file.close()
    except:
        # File didn't exist create it!
        # FIXME: support for diffrent ranges would be nice!
        rrdtool.create( "%s/%s-%s.rrd" %( path, host, sensor ),
                        '-s', '600', "DS:%s:GAUGE:1200:-300:300" % sensor,
                        "RRA:AVERAGE:0.5:1:9600" )
        print "Created new rrd file"
        
    
    print "%s: %s %sC @ %s" %( strftime( "%x %H:%M" ), sensor, value, host )
    rrdtool.update( "%s/%s-%s.rrd" %( path, host, sensor ),
                    "-t%s" % sensor , "N:%s" % value )

# -- main --
if __name__ == '__main__':
    # 10min, logga HDD temp, enbart 1 data fält
    # (temp timeout 1200sek)
    # rrdtool create testfil.rrd -s 600  DS:sda:GAUGE:1200:-300:300 RRA:AVERAGE:0.5:1:9600
    # Exempel på hur denna såg ut...
    print "dumbfetcher/logger test"
    
    HOSTS=["dunwich", "arkham", "ulthar.vpn"]
    PATH="testdata"
    
    while True:
        for x in HOSTS:
            #try:
            for sensor in fetch( x ):
                log( PATH, x, sensor[0], sensor[1] )
            #except:
            #    print "Failed to connect to %s, skipping" % x
        
        sleep( 600 )
